@@ -7,4 +7,6 @@ from .CommentThreads import CommentThread
 from .I18ns import I18n
 from .VideoExtras import VideoCategory, VideoAbuseReportReason
 from .Channels import Channel
-from .ChannelSections import ChannelSection
\ No newline at end of file
+from .ChannelSections import ChannelSection
+from .Searches import Search
+from .Subscriptions import Subscription
\ No newline at end of file
